rayoptics.parax package
=======================

.. automodule:: rayoptics.parax
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   rayoptics.parax.diagram
   rayoptics.parax.etendue
   rayoptics.parax.firstorder
   rayoptics.parax.idealimager
   rayoptics.parax.paraxialdesign
   rayoptics.parax.specsheet
   rayoptics.parax.thirdorder
